@@ -30,8 +30,11 @@ class ProcessPool(object):
     
     @ivar maxIdle: Maximum number of seconds of indleness in a child
     
-    @ivar recycleAfter: Maximum number of calls before restarting a subprocess,
-                        0 to not recycle.
+    @ivar recycleAfter: Maximum number of calls before restarting a
+                        subprocess, 0 to not recycle.
+    
+    @ivar childReactor: The shortName of the reactor to be used in
+                        each child process
     """
 
     finished = False
@@ -40,7 +43,8 @@ class ProcessPool(object):
 
     processFactory = staticmethod(startAMPProcess)
     
-    def __init__(self, ampChild=None, ampParent=None, min=5, max=20, name=None, maxIdle=20, recycleAfter=30):
+    def __init__(self, ampChild=None, ampParent=None, min=5, max=20,
+                 name=None, maxIdle=20, recycleAfter=500, childReactor="select"):
         self.ampParent = ampParent
         self.ampChild = ampChild
         if ampChild is None:
@@ -51,6 +55,7 @@ class ProcessPool(object):
         self.name = name
         self.maxIdle = maxIdle
         self.recycleAfter = recycleAfter
+        self.childReactor = childReactor
         self._queue = []
         
         self.processes = set()
@@ -83,7 +88,8 @@ class ProcessPool(object):
         d = []
         for child, lastUse in self._lastUsage.iteritems():
             if len(self.processes) > self.min and (n - lastUse) > self.maxIdle:
-                # we are setting lastUse when processing finishes, it might be processing right now
+                # we are setting lastUse when processing finishes, it
+                # might be processing right now
                 if child not in self.busy: 
                     # we need to remove this child from the ready set
                     # and the processes set because otherwise it might
@@ -152,7 +158,10 @@ class ProcessPool(object):
             # You might end up with a dirty reactor due to the stop()
             # returning before the new process is created.
             return
-        child, finished = self.processFactory(self.ampChild, ampParent=self.ampParent, packages=('twisted', 'ampoule'))
+        child, finished = self.processFactory(self.ampChild,
+                                              ampParent=self.ampParent,
+                                              childReactor=self.childReactor,
+                                              packages=('twisted', 'ampoule'))
         return self._addProcess(child, finished)
     
     def _cb_doWork(self, command, _d=None, **kwargs):
@@ -200,10 +209,12 @@ class ProcessPool(object):
             # it does so mark this child, using a closure, to be
             # removed at the end of the call.
             die = True
-        return child.callRemote(command, **kwargs
+
+        # If the command doesn't require a response then callRemote
+        # returns nothing, so we prepare for that too.
+        return defer.maybeDeferred(child.callRemote, command, **kwargs
             ).addCallback(_returned, child
             ).addErrback(_returned, child, is_error=True)
-
     
     def doWork(self, command, **kwargs):
         """
